summaryrefslogtreecommitdiffstats
path: root/korganizer/kodaymatrix.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/kodaymatrix.h')
-rw-r--r--korganizer/kodaymatrix.h27
1 files changed, 14 insertions, 13 deletions
diff --git a/korganizer/kodaymatrix.h b/korganizer/kodaymatrix.h
index 3752d52f6..443ecc0e4 100644
--- a/korganizer/kodaymatrix.h
+++ b/korganizer/kodaymatrix.h
@@ -20,8 +20,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef KODAYMATRIX_H
#define KODAYMATRIX_H
@@ -53,19 +53,19 @@ using namespace KCal;
* This class asks the day matrix object for a appropriate label which
* is in our special case the name of the holiday or null if this day is no holiday.
*/
-class DynamicTip : public QToolTip
+class DynamicTip : public TQToolTip
{
public:
/**
* Constructor that expects a KODayMatrix object as parent.
*
* @param parent the parent KODayMatrix control.
*/
- DynamicTip( TQWidget *parent );
+ DynamicTip( TQWidget *tqparent );
protected:
/**
* Qt's callback to ask the object to provide an approrpiate text for the
* tooltip to be shown.
*
* @param pos coordinates of the mouse.
@@ -73,14 +73,14 @@ class DynamicTip : public QToolTip
void maybeTip( const TQPoint &pos );
private:
/** the parent control this tooltip is designed for. */
KODayMatrix *mMatrix;
};
/**
* Replacement for kdpdatebuton.cpp that used 42 widgets for the day matrix to be displayed.
* Cornelius thought this was a waste of memory and a lot of overhead.
- * In addition the selection was not very intuitive so I decided to rewrite it using a QFrame
+ * In addition the selection was not very intuitive so I decided to rewrite it using a TQFrame
* that draws the labels and allows for dragging selection while maintaining nearly full
* compatibility in behavior with its predecessor.
*
@@ -91,7 +91,7 @@ class DynamicTip : public QToolTip
* o no support for Ctrl+click to create groups of dates
* (This has not really been supported in the predecessor. It was not very intuitive nor was it
* user friendly.)
- * This feature has been tqreplaced with dragging a selection on the matrix. The matrix will
+ * This feature has been replaced with dragging a selection on the matrix. The matrix will
* automatically choose the appropriate selection (e.g. you are not any longer able to select
* two distinct groups of date selections as in the old class)
* o now that you can select more then a week it can happen that not all selected days are
@@ -105,14 +105,15 @@ class DynamicTip : public QToolTip
class KODayMatrix: public TQFrame, public KCal::Calendar::Observer
{
Q_OBJECT
+ TQ_OBJECT
public:
/** constructor to create a day matrix widget.
*
* @param parent widget that is the parent of the day matrix.
* Normally this should be a KDateNavigator
* @param name name of the widget
*/
- KODayMatrix( TQWidget *parent, const char *name );
+ KODayMatrix( TQWidget *tqparent, const char *name );
/** destructor that deallocates all dynamically allocated private members.
*/
@@ -121,7 +122,7 @@ class KODayMatrix: public TQFrame, public KCal::Calendar::Observer
/** returns the first and last date of the 6*7 matrix that displays @p month
* @param month The month we want to get matrix boundaries
*/
- static QPair<TQDate,TQDate> matrixLimits( const TQDate &month );
+ static TQPair<TQDate,TQDate> matrixLimits( const TQDate &month );
/**
Associate a calendar with this day matrix. If there is a calendar, the day
@@ -53,19 +53,19 @@ using namespace KCal;
public:
/**
- * Constructor that expects a KODayMatrix object as parent.
+ * Constructor that expects a KODayMatrix object as tqparent.
*
@@ -53,19 +53,19 @@ using namespace KCal;
*
- * @param parent the parent KODayMatrix control.
+ * @param tqparent the tqparent KODayMatrix control.
*/
@@ -53,19 +53,19 @@ using namespace KCal;
protected:
/**
- * Qt's callback to ask the object to provide an approrpiate text for the
+ * TQt's callback to ask the object to provide an approrpiate text for the
* tooltip to be shown.
*
@@ -73,14 +73,14 @@ class DynamicTip : public QToolTip
void maybeTip( const TQPoint &pos );
private:
- /** the parent control this tooltip is designed for. */
+ /** the tqparent control this tooltip is designed for. */
KODayMatrix *mMatrix;
};
@@ -105,14 +105,15 @@ class DynamicTip : public QToolTip
/** constructor to create a day matrix widget.
*
- * @param parent widget that is the parent of the day matrix.
+ * @param tqparent widget that is the tqparent of the day matrix.
* Normally this should be a KDateNavigator
* @param name name of the widget